"""Main module."""

def return_iso(
    api_key,
    locations,
    range,
    profile='driving-car'
    ): 
    
    """ :param locations: pair of lng,lat coordinates in the format of: [[lng, lat], [-48.51057, -27.57482]]
    :type list of coordinates

    :param profile: mode of transportation. One of “driving-car”, “foot-walking”, “cycling-regular”. Defaults to driving-car
    :type string

    :param range: time in minutes that, coupled with the profile, define the equidistant isochrone
    :type integer

    :param api_key: key necessary for making requests to the open route service api. Get yours at: openrouteservice.org
    :type string """

    range_in_secs = [x * 60 for x in range] 

    body = {
        "locations":locations,
        "range": range_in_secs
    }

    headers = {
        'Accept': 'application/json, application/geo+json, application/gpx+xml, img/png; charset=utf-8',
        'Authorization': api_key,
        'Content-Type': 'application/json; charset=utf-8'
    }
    
    call = requests.post('https://api.openrouteservice.org/v2/isochrones/' + profile + '/geojson', json=body, headers=headers)

    print(call.status_code, call.reason)
    response=json.loads(call.text)

    return(response)


#!/usr/bin/env python

"""Tests for `geospots` package."""


import unittest
from click.testing import CliRunner

from geospots import geospots
from geospots import cli


class TestGeospots(unittest.TestCase):
    """Tests for `geospots` package."""

    def setUp(self):
        """Set up test fixtures, if any."""

    def tearDown(self):
        """Tear down test fixtures, if any."""

    def test_return_iso(self):
        """Test that an isochrone within Indicium returns a polygon."""
        test_this = return_iso(
            api_key='5b3ce3597851110001cf62488b98dba3f6c7452b9d391c8306afa037',
            locations=[[-48.51057, -27.57482]],
            profile='driving-car',
            range=[5]
        )


    def test_command_line_interface(self):
        """Test the CLI."""
        runner = CliRunner()
        result = runner.invoke(cli.main)
        assert result.exit_code == 0
        assert 'geospots.cli.main' in result.output
        help_result = runner.invoke(cli.main, ['--help'])
        assert help_result.exit_code == 0
        assert '--help  Show this message and exit.' in help_result.output
